@@ -125,7 +125,7 @@ class MetricsInterceptor(ServerInterceptor):
             grpc_code = STATUS_CODE_BY_INT_VALUE.get(
                 servicer_context.code(), StatusCode.UNKNOWN
             )
-            logger.error(f"[{grpc_code}] {error.details()}")
+            logger.error(f"[{grpc_code}] {error}")
             raise error
 
         finally:
